<?php


// Include template function file

require( plugin_dir_path( __FILE__ ) . '/settings/settings-functions.php');
require( plugin_dir_path( __FILE__ ) . '/meta/meta-functions.php');
require( plugin_dir_path( __FILE__ ) . '/options/option-functions.php');


// Include backend javascript

add_action( 'admin_enqueue_scripts', 'asp_backend_javascript' );
function asp_backend_javascript() {
		wp_enqueue_script( 'asp-backend-javascript', plugins_url( '/settings/js/asp-backend.js', __FILE__ ));
}


// Add settings to sermon menu

add_action('admin_menu', 'asp_setup_settings_menu');
function asp_setup_settings_menu()
{
		add_submenu_page( 'edit.php?post_type=sermons', 'General Settings', 'General Settings', 'administrator', 'asp-settings', 'asp_settings');

		// Show Buy Pro Version if pro version is not installed
		if (!is_plugin_active('advanced-sermons-pro/advanced-sermons-pro.php') ) {
		  	add_submenu_page( 'edit.php?post_type=sermons', 'Buy Pro Version', 'Buy Pro Version', 'administrator', 'asp-settings&page=asp-settings&tab=upgrade', 'asp_settings');
		}
		// Show Activate License if pro version is installed
		if (is_plugin_active('advanced-sermons-pro/advanced-sermons-pro.php') ) {
		  	add_submenu_page( 'edit.php?post_type=sermons', 'Activate License', 'Activate License', 'administrator', 'asp-settings&page=asp-settings&tab=activate', 'asp_settings');
		}
}


// Custom save changes option notice

function asp_custom_save_notice() {
    global $pagenow;
    if ($pagenow == 'edit.php') {
        if ( isset( $_GET['settings-updated'] )) {
            add_settings_error( 'asp-notices', 'asp-settings-updated', __('Settings saved.', 'asp'), 'updated' );
        }
    }
}
add_action('admin_notices', 'asp_custom_save_notice');


// Add view count for sermons

function setSermonsViews($post_id) {
$asp_disable_view_count = get_option( 'asp_general_disable_view_count' );
if ( current_user_can( 'manage_options' )) {
    // Do nothing
} else {
    $count_key = 'post_views_count';
    $count = get_post_meta($post_id, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($post_id, $count_key);
        add_post_meta($post_id, $count_key, '0');
    }else{
        $count++;
        update_post_meta($post_id, $count_key, $count);
    }
}
}
function getSermonsViews($post_id){
$asp_disable_view_count = get_option( 'asp_general_disable_view_count' );
if (!empty($asp_disable_view_count)) {
    $count_key = 'post_views_count';
    $count = get_post_meta($post_id, $count_key, true);
    if(empty($count)){
        delete_post_meta($post_id, $count_key);
        add_post_meta($post_id, $count_key, '0');
        return "0 View";
    }
    return $count.' Views';
}
}


// Add sermon views to WordPress columns

add_filter('manage_sermons_posts_columns', 'sermons_column_views');
add_action('manage_sermons_posts_custom_column', 'sermons_custom_column_views',5,2);
function sermons_column_views($defaults) { $defaults['post_views'] = __('Views'); return $defaults; } function sermons_custom_column_views($column_name, $id){ if($column_name === 'post_views'){ echo getSermonsViews(get_the_ID()); } }


// Change sermon date to preacher date and change order

function add_ourteam_columns ( $columns ) {
unset($columns['date']);
return array_merge ( $columns, array (
 'date' => __('Preached Date')
) );

}

add_filter ( 'manage_sermons_posts_columns', 'add_ourteam_columns' );


// Filter sermons by custom taxonomy

function rudr_posts_taxonomy_filter() {
	global $typenow; // this variable stores the current custom post type
	if( $typenow == 'sermons' ){ // choose one or more post types to apply taxonomy filter for them if( in_array( $typenow  array('post','games') )
		$taxonomy_names = array('sermon_speaker', 'sermon_topics', 'sermon_series');
		foreach ($taxonomy_names as $single_taxonomy) {
			$current_taxonomy = isset( $_GET[$single_taxonomy] ) ? $_GET[$single_taxonomy] : '';
			$taxonomy_object = get_taxonomy( $single_taxonomy );
			$taxonomy_name = strtolower( $taxonomy_object->labels->name );
			$taxonomy_terms = get_terms( $single_taxonomy );
			if(count($taxonomy_terms) > 0) {
				echo "<select name='$single_taxonomy' id='$single_taxonomy' class='postform'>";
				echo "<option value=''>All $taxonomy_name</option>";
				foreach ($taxonomy_terms as $single_term) {
					echo '<option value='. $single_term->slug, $current_taxonomy == $single_term->slug ? ' selected="selected"' : '','>' . $single_term->name .' (' . $single_term->count .')</option>';
				}
				echo "</select>";
			}
		}
	}
}

add_action( 'restrict_manage_posts', 'rudr_posts_taxonomy_filter' );


// Include color picker assets

add_action( 'admin_enqueue_scripts', 'asp_add_color_picker' );
function asp_add_color_picker( $hook ) {
    if( is_admin() ) {
        // Add the color picker css file
        wp_enqueue_style( 'wp-color-picker' );
        // Include our custom jQuery file with WordPress Color Picker dependency
    }
}


// Upload Image Engine

function asp_load_media_files() {
    wp_enqueue_media();
}
add_action( 'admin_enqueue_scripts', 'asp_load_media_files' );


/* Manage Sermons Admin Bar quick links */

add_action('admin_bar_menu', 'asp_admin_bar_manage_sermons', 70);
function asp_admin_bar_manage_sermons($admin_bar){
		$asp_toolbar_menu = get_option( 'asp_general_toolbar_menu' );
		$sermon_label = get_option( 'asp_general_sermon_label' );
		$speaker_label = get_option( 'asp_general_speaker_label' );
		$topic_label = get_option( 'asp_general_topic_label' );
		if (!empty($sermon_label)) {
				$sermon_label = $sermon_label;
				$sermon_label_slug = strtolower("$sermon_label");
		} else {
				$sermon_label = 'Sermon';
				$sermon_label_slug = strtolower("Sermon");
		}
		if (!empty($speaker_label)) {
				$speaker_label = $speaker_label;
				$speaker_label_slug = strtolower($speaker_label);
		} else {
				$speaker_label = 'Speaker';
				$speaker_label_slug = strtolower("Speaker");
		}
		if (!empty($topic_label)) {
				$topic_label = $topic_label;
				$topic_label_slug = strtolower("$topic_label");
		} else {
				$topic_label = 'Topic';
				$topic_label_slug = strtolower("Topic");
		}
		if (empty($asp_toolbar_menu)) {
		    $admin_bar->add_menu( array(
		        'id'    => 'asp-sermons',
		        'title' => "Manage {$sermon_label}s",
		        'href'  => '/wp-admin/edit.php?post_type=sermons',
		        'meta'  => array(
		            'title' => __("Manage {$sermon_label}s"),
		        ),
		    ));
		    $admin_bar->add_menu( array(
		        'id'    => 'asp-sermons-all',
		        'parent' => 'asp-sermons',
		        'title' => "All {$sermon_label}s",
		        'href'  => '/wp-admin/edit.php?post_type=sermons',
		        'meta'  => array(
		            'title' => __("All {$sermon_label}s"),
		            'target' => '_self',
		            'class' => 'asp-sermons-all-link'
		        ),
		    ));
		    $admin_bar->add_menu( array(
		        'id'    => 'asp-sermons-new',
		        'parent' => 'asp-sermons',
		        'title' => "Add $sermon_label",
		        'href'  => '/wp-admin/post-new.php?post_type=sermons',
		        'meta'  => array(
		            'title' => __("Add $sermon_label"),
		            'target' => '_self',
		            'class' => 'asp-sermons-new-link'
		        ),
		    ));
				$admin_bar->add_menu( array(
		        'id'    => 'asp-sermons-speakers',
		        'parent' => 'asp-sermons',
		        'title' => "{$speaker_label}s",
		        'href'  => '/wp-admin/edit-tags.php?taxonomy=sermon_speaker&post_type=sermons',
		        'meta'  => array(
		            'title' => __("{$speaker_label}s"),
		            'target' => '_self',
		            'class' => 'asp-sermons-speakers-link'
		        ),
		    ));
				$admin_bar->add_menu( array(
		        'id'    => 'asp-sermons-topics',
		        'parent' => 'asp-sermons',
		        'title' => "{$topic_label}s",
		        'href'  => '/wp-admin/edit-tags.php?taxonomy=sermon_topics&post_type=sermons',
		        'meta'  => array(
		            'title' => __("{$topic_label}s"),
		            'target' => '_self',
		            'class' => 'asp-sermons-topics-link'
		        ),
		    ));
				$admin_bar->add_menu( array(
		        'id'    => 'asp-sermons-series',
		        'parent' => 'asp-sermons',
		        'title' => 'Series',
		        'href'  => '/wp-admin/edit-tags.php?taxonomy=sermon_series&post_type=sermons',
		        'meta'  => array(
		            'title' => __('Series'),
		            'target' => '_self',
		            'class' => 'asp-sermons-series-link'
		        ),
		    ));
		}
}
